# -*- coding: utf-8 -*-
import os, sys
import xbmcaddon, xbmcgui, xbmc
import traceback, urllib, hashlib

if sys.version_info >= (2,7): import json as _json
else: import simplejson as _json

scriptID = 'plugin.video.polishtv.live'
scriptname = "Polish Live TV"
ptv = xbmcaddon.Addon(scriptID)

BASE_IMAGE_PATH = 'http://sd-xbmc.org/repository/xbmc-addons/'
BASE_RESOURCE_PATH = os.path.join( ptv.getAddonInfo('path'), "../resources" )
sys.path.append( os.path.join( BASE_RESOURCE_PATH, "lib" ) )

import sdLog, sdParser, sdCommon, sdNavigation, sdErrors

log = sdLog.pLog()

SERVICE = 'nadajemytv'
LOGOURL = BASE_IMAGE_PATH + SERVICE + '.png'
MAINURL = 'http://nadajemy.tv/api/api.php'

login = ptv.getSetting('nadajemytv_login')
password = ptv.getSetting('nadajemytv_password')

class nadajemytv:
    def __init__(self):
        log.info('Loading ' + SERVICE)
        self.parser = sdParser.Parser()
        self.exception = sdErrors.Exception()
        self.gui = sdNavigation.sdGUI()
        self.common = sdCommon.common()
        self.login()
        self.api = API(login, password)


    def login(self):
        if login == "" or password == "":
            d = xbmcgui.Dialog()
            d.ok("Zarejestruj sie", "Rejestracja jest wymagana do korzystania z serwisu", "Wiecej szczegolow w watku 'nadajemyTV' na forum sd-xbmc.org")
            exit()
    

    def listChannels(self):
        #check for Premium
        results = self.api.getData('getUser',{'email':login,'password':password})
        if results['status'] == 'error':
            xbmc.executebuiltin('XBMC.Notification(nadajemyTV,'+results['msg']+',30000)')            
        
        results = self.api.getData('getChannels')
        for item in results:
            params = {'service': SERVICE, 'name': 'playSelectedVideo', 'id': item['id'], 'title': item['id'], 'icon': item['image'], 'url': item['url']}
            self.gui.addDir(params)
        self.gui.endDir()


    def handleService(self):
        params = self.parser.getParams()
        name = str(self.parser.getParam(params, "name"))
        title = str(self.parser.getParam(params, "title"))
        url = str(self.parser.getParam(params, "url"))

        if name == 'None':
            self.listChannels()
        elif name == 'playSelectedVideo':
            if "rtmp" in url:
                self.common.LOAD_AND_PLAY_VIDEO(url + "?service=1&auth=" + self.api.getHash(), title)
            if "http" in url:
                self.common.LOAD_AND_PLAY_VIDEO(url.replace('http://','http://'+self.api.getCreds()+'@'), title)

class API:
    def __init__(self, login, password):
        self.common = sdCommon.common()
        self.exception = sdErrors.Exception()
        self.login = login
        self.password = password

    def getCreds(self):
        m = urllib.quote_plus(login) + ':' + urllib.quote_plus(password)
        return m


    def getHash(self):
        m = hashlib.md5()
        m.update(login + password)
        return m.hexdigest()


    def getData(self, method, params={}):
        p = ''
        for item in params:
            p = p + '&' + item + '=' + params[item] 
        query_data = { 'url': MAINURL + '?method=' + method + p, 'use_host': False, 'use_cookie': False, 'use_post': False, 'return_data': True}        
        try:
            data = self.common.getURLRequestData(query_data)
        except Exception, exception:
            traceback.print_exc()
            self.exception.getError(str(exception))
            exit()
        return _json.loads(data)
    